const pkg = require('../package')
const request = require('./utils/request');
const log = require('./utils/log');
const context = require('./utils/context');
const { exec } = require('child_process');

module.exports = {

  /**
   * 命令确认执行前处理
   */
  beforeHandler (option, callback) {
    request.get('/cli/version/latest')
      .then(data => {
        context.setIsDebug(option.debug)
        if (data == null) {
          callback()
          return
        }
        if (pkg.version === data.versionNo) {
          callback()
          return
        }
        // 非强制更新 && 已提醒过
        if (!data.isForce && context.getRemindVersion() === data.versionNo) {
          callback()
          return
        }
        // 非强制更新 && 未提醒过
        if (!data.isForce && context.getRemindVersion() !== data.versionNo) {
          log.tip(`发现新的版本v${data.versionNo}，您可以使用coderd update进行更新`)
          log.tip(`版本说明：${data.versionRemark}`)
          context.setRemindVersion(data.versionNo)
          callback()
          return
        }
        // 需强制更新的版本
        log.tip(`发现新的重要版本v${data.versionNo}，正在自动更新，由于使用的是http://registry.npmjs.org镜像，更新可能较慢，请耐心等待...`)
        log.tip(`更新说明：${data.versionRemark}`)
        exec('npm uninstall coderd -g', (err) => {
          if(err) {
            log.error('更新失败，请手动更新')
            return;
          }
          exec('npm install coderd -g --registry http://registry.npmjs.org', (err) => {
            if(err) {
              log.error('更新失败，请手动更新')
              return;
            }
            log.success("更新成功！")
          })
        })
      })
      .catch((e) => {
        log.error(e)
      })
  }
}
