const inquirer = require('inquirer');
const context = require('./utils/context');
const log = require('./utils/log');
const DBUtil = require('./utils/db');
const syntax = require('./utils/syntax')

// 初始化
function init () {
  // 定义问题
  const questions = [
    {
      name: 'host',
      type: 'input',
      message: '请输入数据库主机地址（默认localhost）'
    },
    {
      name: 'port',
      type: 'input',
      message: '请输入数据库端口号（默认3306）'
    },
    {
      name: 'name',
      type: 'input',
      message: '请输入数据库名（必填）'
    },
    {
      name: 'user',
      type: 'input',
      message: '请输入数据库用户名（必填）'
    },
    {
      name: 'password',
      type: 'password',
      message: '请输入数据库密码'
    }
  ];
  inquirer.prompt(questions)
    .then(answers => {
      // 验证
      if (answers.name.trim() === '' || answers.user.trim() === '') {
        log.error('设置数据库失败，缺少必填参数');
        return;
      }
      answers.host = answers.host.trim() === '' ? 'localhost' : answers.host.trim();
      answers.port = answers.port.trim() === '' ? '3306' : answers.port.trim();
      answers.name = answers.name.trim();
      context.setDatabase(answers)
    })
    .catch(e => {
      log.error(e);
    })
}

// 测试连接
function testConnect () {
  DBUtil.connect(true, () => {
    log.success('连接成功')
  })
}

module.exports = {
  handleCommand (command, option, args) {
    if (command !== 'db' && command !== 'database') {
      return false
    }
    syntax.check(args, option, [1]);
    // 测试连接
    if (option.test) {
      // 验证数据库
      if (!context.checkDatabase()) {
        process.exit();
      }
      testConnect();
      return true
    }
    // 初始化
    init();
    return true
  }
};
