const colors = require('colors-console')

// 命令列表
const commands = [
  {
    name: 'login',
    description: '登录',
    space: `\t\t\t`
  },
  {
    name: 'regis',
    description: '注册',
    space: `\t\t\t`
  },
  {
    name: 'logout',
    description: '退出登录',
    space: `\t\t`
  },
  {
    name: 'run',
    description: '使用最后一次配置生成代码',
    space: `\t\t\t`
  },
  {
    name: 'use',
    description: '指定数据',
    space: `\t\t\t`
  },
  {
    name: 'project',
    description: '项目操作',
    space: `\t\t`
  },
  {
    name: 'res',
    description: '项目数据模型操作',
    space: `\t\t\t`
  },
  {
    name: 'table',
    description: '数据库表操作',
    space: `\t\t\t`
  },
  {
    name: 'db, database',
    description: '数据库操作',
    space: `\t\t`
  },
  {
    name: 'update',
    description: '更新命令版本',
    space: `\t\t`
  },
  {
    name: '{template alias}',
    description: '指定模版别名进行代码生成',
    space: `\t`
  },
  {
    name: '{template alias}@{version}',
    description: '指定模版别名及版本号进行代码生成',
    space: ``
  },
  {
    name: '{template alias} {function command}',
    description: '指定模版别名及功能命令进行代码生成',
    space: ``
  }
];
// 参数选项列表
const options = [
  {
    name: '-v, --version',
    description: '查看版本号',
    space: `\t\t`
  },
  {
    name: '-h, --help',
    description: '查看帮助',
    space: `\t\t`
  },
  {
    name: '-l, --list',
    description: '以列表形式展开目标数据',
    space: `\t\t`
  },
  {
    name: '-a, --all',
    description: '同步表时指定该参数表示同步所有表',
    space: `\t\t`
  },
  {
    name: '-f, --force',
    description: '生成代码时指定该参数，表示强制覆盖',
    space: `\t\t`
  },
  {
    name: '-t, --test',
    description: '生成代码时指定该参数，表示使用模版的草稿（用户拥有的草稿）进行生成',
    space: `\t\t`
  },
  {
    name: '-n',
    description: '创建目标数据',
    space: `\t\t\t`
  },
  {
    name: '-p',
    description: '指定项目英文名称',
    space: `\t\t\t`
  },
  {
    name: '-r',
    description: '指定数据模型资源',
    space: `\t\t\t`
  },
  {
    name: '-s',
    description: '指定为同步',
    space: `\t\t\t`
  }
];
// 例子
const egs = [
  {
    command: 'update',
    description: '自动更新命令到最新版本',
    space: `\t\t\t`
  },
  {
    command: 'vue build',
    description: '使用vue模版的默认版本搭建vue框架',
    space: `\t\t`
  },
  {
    command: 'model -r user',
    description: '使用model模版的默认版本生成user表实体',
    space: `\t\t`
  },
  {
    command: 'eva page -r user -f',
    description: '指定使用Eva模版的page功能为user模型生成页面并强制覆盖',
    space: `\t`
  },
  {
    command: 'eva p -r user',
    description: '使用page简写p为为user模型生成页面，简写规则为功能命令单词首字母',
    space: `\t\t`
  },
  {
    command: 'springboot@v2.1.9 build',
    description: '指定使用springboot模版v2.1.9版本构建框架',
    space: ``
  },
  {
    command: 'run',
    description: '使用最后一次配置生成代码',
    space: `\t\t\t`
  },
  {
    command: 'run vue3',
    description: '使用vue3模版最后一次配置生成代码',
    space: `\t\t`
  },
  {
    command: 'project -n',
    description: '创建新项目',
    space: `\t\t`
  },
  {
    command: 'project -l',
    description: '列出所有项目',
    space: `\t\t`
  },
  {
    command: 'use -p test',
    description: '指定英文名为test的项目为默认项目',
    space: `\t\t`
  },
  {
    command: 'res -l',
    description: '列出当前项目下所有数据模型',
    space: `\t\t\t`
  },
  {
    command: 'db',
    description: '初始化数据库信息',
    space: `\t\t\t`
  },
  {
    command: 'db -t',
    description: '测试数据库连接',
    space: `\t\t\t`
  },
  {
    command: 'table -l',
    description: '查询数据库所有的表',
    space: `\t\t`
  },
  {
    command: 'table -s',
    description: '选饿并同步表结构至项目模型中',
    space: `\t\t`
  },
  {
    command: 'table -s user',
    description: '同步user表结构至项目模型中',
    space: `\t\t`
  }
];
// 打印
const print = () => {
  console.log(`${colors('yellow','Usage')}: coderd <alias>@<version> <command> [options]`);
  // Commands
  console.log();
  console.log(`${colors('yellow','Commands')}:`);
  for (const command of commands) {
    console.log(`  ${colors('green', command.name)}${command.space}\t\t${command.description}`)
  }
  // Options
  console.log();
  console.log(`${colors('yellow','Options')}:`);
  for (const option of options) {
    console.log(`  ${colors('green', option.name)}${option.space}\t\t${option.description}`)
  }
  // Examples
  console.log();
  console.log(`${colors('yellow','Examples')}:`);
  for (const eg of egs) {
    console.log(`  ${colors('green', 'coderd ' + eg.command)}${eg.space}\t${eg.description}`)
  }
};

module.exports = {
  handleCommand () {
    const nodeArgs = process.argv.slice(2);
    if (nodeArgs.length == 0 || nodeArgs[0] === '--help' || nodeArgs[0] === '-h') {
      print();
      process.exit();
    }
  }
};
