const request = require('./utils/request');
const log = require('./utils/log');
const syntax = require('./utils/syntax');
const context = require('./utils/context');

// 查询数据模型
function fetchResources () {
  log.info('正在查询项目数据模型...');
  request.post('/cli/project/query/dms', {projectId: context.getProject()})
    .then(dms => {
      for (const dm of dms) {
        log.info(`${dm.modelType}\t ${dm.name}${dm.remark === '' ? '' : ('/' + dm.remark)}`);
      }
      log.success(`查询完成，共查询到 ${dms.length} 个数据模型`);
    })
    .catch(e => {
      // 不属于项目成员
      if (e.code === '000104') {
        log.warn('查询失败！您不属于该项目成员。')
        process.exit();
      }
      log.error(e);
    })
}
module.exports = {
  handleCommand(command, option, args) {
    if (command !== 'res') {
      return false
    }
    syntax.check(args, option, [1]);
    // 查询项目模型
    if (context.getProject() == null) {
      log.warn(`当前没有指定默认项目，你可以通过coderd project -l查询你拥有的所有项目，并通过coderd use -p <project-english-name>来指定默认项目`);
      process.exit();
    }
    fetchResources();
    return true;
  }
};
