const inquirer = require('inquirer');
const requestSystem = require('./utils/request-user');
const requestApp = require('./utils/request');
const context = require('./utils/context');
const log = require('./utils/log');
// 获取问题
function getQuestions () {
  return [
    {
      type: 'input',
      name: 'username',
      message: '用户名/手机号码',
      validate (value) {
        if (value.trim() === '') {
          return `请输入用户名或手机号码`
        }
        return true
      }
    },
    {
      type: 'password',
      name: 'password',
      message: '请输入密码',
      validate (value) {
        if (value.trim() === '') {
          return `请输入密码`
        }
        return true
      }
    }
  ];
}

// 登录
function login () {
  inquirer.prompt(getQuestions())
    .then(answers => {
      return requestSystem.post('/cli/usr/login', {
        account: answers.username,
        pwd: answers.password,
        sign: {
          appId: '190001',
          redirectUri: 'http://coderd.adjustrd.com/usr/autologin',
          digest: '5f75f47fcecdef5a547a885439281b17d077ac18059600950bf93782b793ebf60fd5853d0c14b67e47a4c71964920c15'
          // redirectUri: 'http://localhost:3001/usr/autologin',
          // digest: '1c4bfc2f1359f45b2bd7cfbd8432ea3188c877e6275d557e48a13ddf1b84ef53da46199a1517001ba65a192a3076f3a0'
        }
      })
        .then(data => {
          return data
        })
        .catch(e => {
          if (e.code === '010001' || e.code === '010002') {
            log.warn('用户名或密码错误');
            process.exit()
          }
          log.error(e);
          process.exit()
        })
    })
    .then(sysdata => {
      return requestApp.post('/login', {
        accessToken: sysdata.access_token.token,
        timestamp: sysdata.access_token.timestamp,
        digest: sysdata.access_token.digest,
      })
        .then(data => {
          context.initHomeContext(data.token);
          context.initProjectContext();
          log.success('登录成功')
        })
        .catch(e => {
          log.error(e);
          process.exit()
        })
    })
}

// 注册
function regis () {
  const child_process = require('child_process');
  const url = "http://coderd.adjustrd.com";
  let cmd = 'open';
  switch (process.platform) {
    case 'win32':
      cmd = 'start';
      break;

    case 'linux':
      cmd = 'xdg-open';
      break;

    case 'darwin':
      cmd = 'open';
      break;
  }
  try {
    child_process.exec(`${cmd} ${url}`);
  } catch (e) {
    Console.error('您的系统无法自动打开浏览器，前往http://coderd.adjustrd.com/注册')
  }
}

// 退出登录
function logout () {
  return requestApp.post('/logout')
    .then(() => {
      log.success('退出成功')
    })
    .catch(e => {
      log.error(e)
    })
}

module.exports = {
  handleCommand (command) {
    if (command === 'login') {
      login();
      return true
    }
    if (command === 'regis') {
      regis();
      return true
    }
    if (command === 'logout') {
      logout();
      return true
    }
  }
};
