const context = require('./context');
const log = require('./log');
const mysql = require('mysql');

module.exports = {
  // 获取所有表
  getTables (callback) {
    this.connect(false, ({connection}) => {
      connection.query(`SELECT * FROM information_schema.TABLES WHERE TABLE_SCHEMA = '${context.getDatabase().name}'`, function (error, tables, fields) {
        if (error) {
          log.error(error)
          return
        }
        callback && callback({
          tables: tables.map(table => {
            return {
              name: table.TABLE_NAME,
              remark: table.TABLE_COMMENT
            }
          })
        })
        connection.end()
      })
    })
  },
  // 获取所有表
  getFields (tableName, callback) {
    this.connect(false, ({connection}) => {
      connection.query(`SELECT * FROM information_schema.columns WHERE table_name='${tableName}' AND table_schema='${context.getDatabase().name}' ORDER BY ORDINAL_POSITION ASC`, function (error, results, fields) {
        if (error) {
          log.error(error)
          return
        }
        callback && callback({
          fields: results.map(field => {
            // 获取长度和精度，如果type存在'('，则表示type为诸如varchar(200)的格式，此时需要获取长度和精度
            let index = field.COLUMN_TYPE.indexOf('(')
            let length = 0
            let decimal = 0
            if (index !== -1) {
              let secondInfo = field.COLUMN_TYPE.substring(index + 1, field.COLUMN_TYPE.indexOf(')'))
              length = secondInfo.split(',')[0].trim()
              decimal = secondInfo.split(',')[1] == null ? 0 : secondInfo.split(',')[1].trim()
            }
            return {
              name: field.COLUMN_NAME,
              type: field.DATA_TYPE.toUpperCase(),
              length,
              decimal,
              defaultValue: field.COLUMN_DEFAULT,
              required: field.IS_NULLABLE === 'NO',
              isPrimaryKey: field.COLUMN_KEY === 'PRI',
              isAutoIncrement: field.EXTRA === 'auto_increment',
              remark: field.COLUMN_COMMENT
            }
          })
        })
        connection.end()
      })
    })
  },
  // 连接数据库
  connect (test = false, callback = () => {}) {
    const dbConfig = context.getDatabase()
    dbConfig.database = dbConfig.name
    const connection = mysql.createConnection(dbConfig)
    connection.connect((error) => {
      if (error) {
        log.error('数据库连接失败')
        console.error(error)
        return
      }
      callback({connection})
    })
    if (test) {
      connection.end()
    }
  }
}
