const log = require('./log');
const axios = require('axios')
const context = require('./context')
axios.defaults.headers.common['Content-Type'] = 'application/json;charset=UTF-8'
const axiosInstance = axios.create({
  // 如果是服务端请求，基础路径为后端地址，如果为客户端请求，基础路径为客户端根路径
  // baseURL: 'http://localhost:9100',
  baseURL: 'http://coderd.adjustrd.com/api',
  timeout: 180000 // 请求超时时间
})

// 添加请求拦截器
axiosInstance.interceptors.request.use(function (config) {
  log.debug('request: interceptors.request')
  const userToken = context.getUserToken();
  if (userToken != null) {
    config.headers['X-User-Token'] = userToken
  }
  return config
}, function (error) {
  log.debug('request: interceptors.request throw an error.')
  return Promise.reject(error)
})
// 添加响应拦截器
axiosInstance.interceptors.response.use(response => {
  log.debug('request: interceptors.response')
  // 请求失败
  if (response.status !== 200) {
    log.debug('request: response.status = ' + response.status)
    return Promise.reject(response.data)
  }
  // 业务失败
  if (response.data.code !== '000000') {
    log.debug('request: response.data.code = ' + response.data.code)
    return Promise.reject(response.data)
  }
  return response.data.data
}, function (error) {
  log.debug('request: interceptors.response throw an error.')
  // 对响应错误做点什么
  return Promise.reject(error)
})

module.exports = axiosInstance
